﻿using System;
using System.Drawing;
using Xamarin.Forms.Platform.iOS;
using MonoTouch.UIKit;
using Xamarin.Forms;
using ThinkGeo.MapSuite.iOSEdition;
using ThinkGeo.MapSuite.Core;


// This ExportRenderer command tells Xamarin.Forms to use this renderer
// instead of the built-in one for this page
[assembly: ExportRenderer(typeof(Forms2Native.MyThirdPage), typeof(Forms2Native.MyThirdPageRenderer))]

namespace Forms2Native
{
    /// <summary>
    /// Render this page using platform-specific UIKit controls
    /// </summary>
    public class MyThirdPageRenderer : PageRenderer
    {
        protected override void OnModelSet(Xamarin.Forms.VisualElement model)
        {
            base.OnModelSet(model);

            var page = model as MyThirdPage;

            var hostViewController = ViewController;

            var viewController = new UIViewController();
            viewController.View.Frame = UIScreen.MainScreen.Bounds;
            viewController.View.BackgroundColor = UIColor.White;
            viewController.View.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;

            //var label = new UILabel(new RectangleF(0, 40, 320, 40));
            //label.Text = "3 " + page.Heading;
            //viewController.View.Add(label);

            MapView iOSMap = new MapView(viewController.View.Frame);
            iOSMap.MapUnit = GeographyUnit.DecimalDegree;
            iOSMap.BackgroundColor = UIColor.FromRGB(153, 179, 204);
            iOSMap.CurrentExtent = new RectangleShape(-133.2515625, 89.2484375, 126.9046875, -88.290625);
            viewController.View.Add(iOSMap);

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer("AppData/Countries02.shp");
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(worldLayer);
            iOSMap.Overlays.Add(layerOverlay);

            Marker thinkGeoLocation = new Marker();
            thinkGeoLocation.Position = new PointShape(-96.809523, 33.128675);
            // The old version use this code 
            // thinkGeoLocation.Image = UIImage.FromBundle("Pin");
            thinkGeoLocation.SetImage(UIImage.FromBundle("Pin"), UIControlState.Normal);

            MarkerOverlay markerOverlay = new MarkerOverlay();
            markerOverlay.Markers.Add(thinkGeoLocation);
            iOSMap.Overlays.Add(markerOverlay);

            iOSMap.Refresh();

            hostViewController.AddChildViewController(viewController);
            hostViewController.View.Add(viewController.View);
            viewController.DidMoveToParentViewController(hostViewController);
        }
    }
}

